<?php

namespace App\Http\Controllers\Admin;

use App\Helpers\Admin as AdminHelper;
use App\Http\Controllers\Controller;
use App\Models\Admin;
use App\Models\PasswordResetsAdmin;
use Hash;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;
use App\Helpers\LogActivity;

class AuthController extends Controller
{
    public function index()
    {
        // print_r("hello");die;
        if (AdminHelper::checkAdminLogin() == 'success' && AdminHelper::checkLogin() == 'success') {
            return redirect()->route('admin.dashboard');
        } else {
            return view('admin.auth.login');
        }
    }
    public function checkLogin(Request $request)
    {
        // dd($request->all());
        $this->validate($request, [
            'email' => 'required|email',
            'password' => 'required',
        ]);
        $email = $request->email;
        $password = $request->password;
        $getUser = Admin::Email($email)->first();
        

        
        if(!empty($getUser)) {
            if($getUser->role == 2){
            $user_id = $getUser->id;
            $user_role = $getUser->role;
                LogActivity::addToLog($user_id,$user_role);
        }
       // dd($request->all());

            if (Hash::check($password, $getUser->password) == true ) {
                AdminHelper::setSession($getUser->id, $getUser->role);
                if ($request->rememberme === 'on') {
                    AdminHelper::setRememberMeCookie($email, $password);
                } else {
                    AdminHelper::destroyRememberMeCookie();
                }
                return redirect()->route('admin.dashboard');
            }elseif($getUser->status == 0){
                 AdminHelper::flashSessionMessage('error', 'Your account is deactivated');
                return redirect()->back()->withInput($request->all());
            }
            AdminHelper::flashSessionMessage('error', trans('messages.invalid_credentials'));
            return redirect()->back()->withInput($request->all());
        } else {
            AdminHelper::flashSessionMessage('error', trans('messages.invalid_credentials'));
            return redirect()->back()->withInput($request->all());
        }
    }

    public function logout()
    {
        AdminHelper::destroySession();
        return redirect()->route('admin.login');
    }
    public function changePassword()
    {
        return view('admin.changePassword');
    }
    public function updatePassword(Request $request)
    {
        $this->validate($request, [
            'current_password' => 'required',
            'new_password' => 'required|min:8|max:30',
            'confirm_new_password' => 'required|same:new_password',
        ]);
        $admin = AdminHelper::currentUser();
        if (Hash::check($request->current_password, $admin->password) == true) {
            $admin->password = Hash::make($request->new_password);
            $admin->save();
            AdminHelper::flashSessionMessage('success', trans('messages.password_changed'));

            return redirect()->route('admin.dashboard');
        }
        AdminHelper::flashSessionMessage('error', trans('messages.wrong_current_password'));

        return redirect()->back();
    }
    public function forgotPassword()
    {
        return view('admin.auth.forgotPassword');
    }
    public function checkForgotPassword(Request $request)
    {
        $this->validate($request, [
            'email' => ['required', 'email', 'exists:admins'],
        ]);
        $token = md5(time()) . md5(mt_rand(999999999, 99999999999999));
        $match = [
            'email' => $request->email,
        ];
        $storeData = [
            'token' => $token,
            'created_at' => now(),
        ];
        PasswordResetsAdmin::updateOrCreate($match, $storeData);
        $admin = Admin::Email($request->email)->first();
    
        Mail::send('email.resetpassword-admin-email', ['token' => $token, 'userdetail' => $admin], function ($message) use ($admin) {
            $message->to($admin->email, $admin->name)->subject('Instructions to reset password');
            $message->from(env('MAIL_FROM_ADDRESS'), env('MAIL_FROM_NAME'));
        });
        
        AdminHelper::flashSessionMessage('success', trans('messages.reset_password_email_sent'));

        return redirect()->route('admin.login');
    }
    public function checkResetPasswordToken($token)
    {
        if (empty($token)) {
            AdminHelper::flashSessionMessage('error', trans('messages.invalid_reset_password_link'));
            return redirect()->route('admin.login');
        }
        $token = PasswordResetsAdmin::where('token', $token)->first();
        if (empty($token)) {
            AdminHelper::flashSessionMessage('error', trans('messages.invalid_reset_password_link'));
            return redirect()->route('admin.login');
        }
        $currentTime = time();
        $t = strtotime($token->created_at) + 60 * 60;
        $expiry = date("Y-m-d H:i:s", $t);
        $expiryTime = strtotime($expiry);
        if ($currentTime > $expiryTime) {
            AdminHelper::flashSessionMessage('error', trans('messages.reset_password_link_expired'));
            return redirect()->route('admin.login');
        }

        return view('admin.auth.resetPassword', compact('token'));
    }
    public function setNewPassword(Request $request, $token)
    {
        $this->validate($request, [
            'new_password' => 'required|min:8|max:30',
            'confirm_new_password' => 'required|min:8|max:30|same:new_password',
        ]);
        $checkToken = PasswordResetsAdmin::Token($token)->first();
        if (empty($checkToken)) {
            AdminHelper::flashSessionMessage('error', trans('messages.invalid_reset_password_link'));
            return redirect()->route('admin.login');
        }
        Admin::Email($checkToken->email)->update(['password' => Hash::make($request->new_password)]);
        $checkToken->delete();
        AdminHelper::flashSessionMessage('success', trans('messages.password_updated'));

        return redirect()->route('admin.login');
    }
    public function isEmailAvailable(Request $request){
       $getUser = Admin::Email($request->email)->first();
        if($getUser){
                   echo json_encode(false);
        }else{
             echo json_encode(true);
        }
    }
   
}
