<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;
use App\Models\Language;
use DataTables;
use App\Models\Notification;
use App\Helpers\s3upload;
use App\Helpers\NotificationHelper;
use Illuminate\Support\Facades\Storage;
use DB;
use App\Helpers\DeleteAffectedHelper;
use Session;
use Mail;
use App\Helpers\Admin;

class CustomNotification extends Controller
{
     /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
    	$permission = Admin::checkPermission(Session::get('user_id'),'Notifications','View');
    
      if($permission == 0){
        
        return redirect()->route('admin.dashboard')->with('message','You dont have permission to do this action')->send();


      }else{
        if ($request->ajax())
        {
            $data = Notification::select('notifications.*','users.full_name')
            ->leftjoin('users','notifications.user_id','=','users.id')
            ->where('notifications.deleted_at','=',null)->where('tag','=','admin_custom_notification')->get();
            return Datatables::of($data)
              ->addIndexColumn()
             
              ->addColumn('created_at', function($row){
                  return date('d-m-Y',strtotime($row->created_at));
              })
              ->addColumn('time', function($row){
                  return date('H:i:s',strtotime($row->created_at));
              })
              ->addColumn('title', function($row){
                   return $row->title;
              })
              ->addColumn('message', function($row){
                   return $row->message;
              })
              ->addColumn('user_id', function($row){
                   return $row->full_name;
              })
            
              ->addColumn('action', function($row){
                  $urlpath = url('admin/notifications');
                  $delete = Admin::checkPermission(Session::get('user_id'),'Notifications','Delete');
                   $btn = '';
                        if($delete == 1){
                            $btn = '<a href="javascript:void(0);" onClick="deleteFunc('.$row->id.')" class="dropdown-item"><i class="zmdi zmdi-delete zmdi-hc-fw text-secondary"></i>Delete</a>';
                  }
                  return '<div class="btn-group dot-view-acation"><a href="#" data-toggle="dropdown" class="btn btn-default btn-sm btn-icon-only transparent" title=""><i class="zmdi zmdi-more"></i></a>
                            <div class="dropdown-menu dropdown-icon-menu dropdown-menu-right"> 
                                                 '.$btn.'</div></div>';

                  //return '<a href="javascript:void(0);" onClick="deleteFunc('.$row->id.')" class="delete"><i class="material-icons">delete</i></a>';
              })
              ->rawColumns(['created_at','time','title','message','user_id','action'])
              ->make(true);
        }
        return view('admin.notification.list');
    }
    }

    public function add(){
    	
            return view('admin.notification.notifications');

    }

      public function SendCustomNotification(Request $request)
    {
    	
        if (in_array('selectall_r', $request->selectedusers)) {
               $users = User::where('user_type','r')->where('status','=','1')->where('is_deleted','=','0')->get();
           // $users = User::where('is_deleted','=','0')->where('user_type','r')->where('is_admin_verify','=','1')->get();
        }elseif(in_array('selectall_c', $request->selectedusers)){
        	// $users = User::where('is_deleted','=','0')->where('user_type','c')->where('status','=','1')->get();
                   $users = User::where('user_type','c')->where('status','=','1')->where('is_deleted','=','0')->get();

        }
        else {
            $users = User::whereIn('id', $request->selectedusers)->where('is_deleted','=','0')->get();
        }
        if (!empty($users)) {
            $userids = $users->pluck('id');
            $admin_id = Session::get('user_id');
            $mobilenumbers =  $users->pluck('mobile_number','country_code');
             NotificationHelper::allnotificationsend($userids, ['admin_id' => $admin_id,'title' => $request->title, 'message' => $request->message, 'tag' => 'admin_custom_notification']);
            if (in_array('sendsms', $request->selectedtype)) {

                $sms_response = NotificationHelper::sendsms($mobilenumbers, $request->message);
                if($sms_response != 'true'){
                    return redirect()->route('admin.notifications.list')->with('error', 'Something wrong to send sms! Please check your unifonic account details');
                }
               

            }

            if (in_array('sendemail', $request->selectedtype)) {
                $title = $request->title;
                $emailmessage = $request->message;

                foreach ($users as $user) {
                    if($user->email != ''){

                       
                    Mail::send('email.custom-email-notification', ['emailmessage' => $emailmessage], function ($message) use ($user, $title) {
                        $message->to($user->email, $user->full_name)->subject($title);
                        $message->from(env('MAIL_FROM_ADDRESS'), env('MAIL_FROM_NAME'));
                    });
                   }
                }
            }
            return redirect()->route('admin.notifications.list')->with('message', 'Notification send successfully!');
        }
    }
    

    public function delete($id){

        $notification = Notification::find($id);
        $notification->deleted_at = now();
        $notification->update();
        return response()->json([
            'success' => 'Notification has been deleted successfully!'
        ]);
    }

    public function GetUserWithtype($type){

       $users = User::where('user_type',$type)->where('status','=','1')->where('is_deleted','=','0')->get();

       foreach ($users as $key => $user) {
       	if($user->user_type == 'r'){

            echo '<option value='.$user["id"].'>'.$user['restaurant_name'].' - '.$user['full_name'].'</option>';
       	}else{
       		 echo '<option value='.$user["id"].'>'.$user['full_name'].'</option>';
       	}
       }
    }
   
    public function view($id) {
        //$user = User::find($id)->toArray();
        $users = DB::table('users')
            ->leftjoin('restaurant_bank_details', 'users.id', '=', 'restaurant_bank_details.user_id')
            ->select('users.*', 'restaurant_bank_details.*')
            ->where('users.id',$id)
            ->get()->first();

        return view('admin.restaurant.view')->with('user',$users);
    }

   
}
