<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\AdminSetting;
use App\Models\TutorialVideo;
use DataTables;
use App\Helpers\s3upload;
use Illuminate\Support\Facades\Storage;

class SettingController extends Controller
{
    /**
     * Seeting List
    */
    public function index(Request $request)
    {
        if ($request->ajax()) {
            $data = AdminSetting::all();
            return Datatables::of($data)
                    ->addIndexColumn()
                    ->addColumn('action', function($row){
                        $urlpath = url('admin/setting');
                        return '<a href="'.$urlpath.'/edit/'. $row['id'] .'" class="edit"><i class="material-icons">edit</i></a>';
                    })
                    ->rawColumns(['action'])
                    ->make(true);
        }
        return view('admin.settings.list');
    }
    
    public function edit($id) {
        $setting = AdminSetting::find($id)->toArray();

        return view('admin.settings.edit')->with('setting', $setting);
    }

    public function update(Request $request){
        $setting = AdminSetting::find($request->setting_id);
        $setting->shipping_charge = $request->shipping_charge;
        $setting->minimum_wallet_balance = $request->minimum_wallet_balance;
        $setting->cancel_duration = $request->cancel_duration;
        $setting->tap_payment_public_key = $request->tap_payment_public_key;
        $setting->tap_payment_secret_key = $request->tap_payment_secret_key;
        $setting->tap_payment_merketplace_key = $request->tap_payment_merketplace_key;
        $setting->tax = $request->tax;
        $setting->update();
        // return redirect()->back()->with('message', 'Category updated successfully!');
        return redirect()->route('admin.setting.list')->with('message', 'Setting record updated successfully!');
    }
    public function update_unifoinic(Request $request){
        $setting = AdminSetting::find($request->setting_id);
        $setting->unifonic_app_id = $request->unifonic_app_id;
        $setting->unifonic_senderid = $request->unifonic_senderid;
        $setting->unifonic_account_email = $request->unifonic_account_email;
        $setting->unifonic_account_password = $request->unifonic_account_password;
        $setting->update();
        return redirect()->route('admin.setting.list')->with('message', 'Setting updated successfully!');
    }


    /**
     * tutorial video List
    */
    public function videoList(Request $request)
    {
        if ($request->ajax()) {
            $data = TutorialVideo::all();
            return Datatables::of($data)
                    ->addIndexColumn()
                    ->addColumn('video', function($row){
                        return env('project_image_path').'video/'.$row->video;
                    })
                    ->addColumn('action', function($row){
                        $urlpath = url('admin/setting');
                        return '<a href="'.$urlpath.'/videoEdit/'. $row['id'] .'" class="edit"><i class="material-icons">edit</i></a>';
                    })
                    ->rawColumns(['video','action'])
                    ->make(true);
        }
        return view('admin.settings.video_list');
    }

    public function videoEdit($id) {
        $video = TutorialVideo::find($id)->toArray();
        return view('admin.settings.video_edit')->with('video', $video);
    }

    public function videoUpdate(Request $request){
        if($request->file('video')){
            $video = TutorialVideo::find($request->id);
            $file1 = $request->file()['video'];
            $videoName=$file1->getClientOriginalName();
            $file = $_FILES['video']['tmp_name'];
            $path = env('AWS_BUCKET_FOLDER') . env('TUTORIAL_VIDEO');
            $contents = s3upload::uploadImage($videoName, $file, $path); // calling helper function
            $video->video = $contents;
            $video->update();
        }
        return view('admin.settings.video_list');
    }
}
