<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;
use App\Models\Language;
use DataTables;
use App\Models\Usersubscription;
use App\Models\Review;
use App\Models\SubscriptionFeature;
use App\Models\Subscription;
use App\Models\SubscriptionAddedfeature;
use App\Helpers\s3upload;
use Illuminate\Support\Facades\Storage;
use DB;
use App\Helpers\DeleteAffectedHelper;
use App\Helpers\Admin;
use Session;

class SubscriptionController extends Controller
{
     /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
     $permission = Admin::checkPermission(Session::get('user_id'),'Subscription','View');
    
      if($permission == 0){
      
          return redirect()->route('admin.dashboard')->with('message','You dont have permission to do this action')->send();


      }else{

        if ($request->ajax())
        {
            $data = Subscription::where('is_deleted','=','0')->get();
            return Datatables::of($data)
              ->addIndexColumn()
             
              ->addColumn('name', function($row){
                  return $row->name;
              })
              ->addColumn('price', function($row){
                  return $row->price;
              })
              ->addColumn('validity', function($row){
                  return $row->validity;
              })
            
              ->addColumn('action', function($row){
                  $urlpath = url('admin/subscription');
                  $update = Admin::checkPermission(Session::get('user_id'),'Subscription','Update');
                  $delete = Admin::checkPermission(Session::get('user_id'),'Subscription','Delete');
                        $btn = '';
                        if($update == 1){
                            $btn = '<a href="'.$urlpath.'/edit/'. $row->id .'" class=" dropdown-item"><i class="zmdi zmdi-edit zmdi-hc-fw text-secondary"></i>Edit</a>';
                  }
                  if($delete == 1){
                           $btn.= '<a href="javascript:void(0);" onClick="deleteFunc('.$row->id.')" class=" dropdown-item"><i class="zmdi zmdi-delete zmdi-hc-fw text-secondary"></i>Delete</a>';
                  }
                  
                  return '<div class="btn-group dot-view-acation"><a href="#" data-toggle="dropdown" class="btn btn-default btn-sm btn-icon-only transparent" title=""><i class="zmdi zmdi-more"></i></a>
                            <div class="dropdown-menu dropdown-icon-menu dropdown-menu-right"> 
                                                 '.$btn.'</div></div>';
              })
              ->rawColumns(['name','price','validity','action'])
              ->make(true);
        }
        return view('admin.subscription.list');
    }
    }

    public function add(){
    	   $features = SubscriptionFeature::get();
    	    return view('admin.subscription.add')->with('features',$features);

    }
    public function addsubscription(Request $request){
    
         $this->validate($request, [
            'subfeature' => 'required',

        ]);
        $added_user_id   = Session::get('user_id');
    	  $subscription = new Subscription();
        $subscription->name = $request->subscription_name;
        $subscription->price = $request->subscription_price;
        $subscription->discount_price = $request->discount_price;
        $subscription->validity = $request->validity;
        $subscription->added_user_id = $added_user_id;
       
        if($subscription->save())
        {
          foreach ($request->subfeature as $key => $value) {
            $sub_per = new SubscriptionAddedfeature();
            $sub_per->subscription_id = $subscription->id;
            $sub_per->features_id = $value;
            $sub_per->save();
          }
         
            return redirect()->route('admin.subscription.list')->with('message', 'Subscription plan added successfully!');
          }
        }
    

    public function edit($id) {
       $subscription = Subscription::where('id',$id)->first();
    

       $parent_permission = SubscriptionAddedfeature::select('subscription_addedfeatures.features_id')
     // ->join('subscription_sub_features','subscription_sub_features.id','=','subscription_addedfeatures.features_id')
      ->join('subscription_features','subscription_features.id','=','subscription_addedfeatures.features_id')
      ->where('subscription_addedfeatures.subscription_id',$subscription->id)
      ->pluck('features_id')->toArray();

      $features = SubscriptionFeature::get();
      return view('admin.subscription.edit', ['subscription'=>$subscription,'features' => $features,'parent_permission'=>$parent_permission]);
        
    }

    public function update(Request $request){
    
    	$add_sub = subscription::where('id', $request->id)->first();
        $added_user_id   = Session::get('user_id');
        $add_sub->name = $request->subscription_name;
        $add_sub->price = $request->subscription_price;
        $add_sub->discount_price = $request->discount_price;
        $add_sub->validity = $request->validity;
        $add_sub->added_user_id = $added_user_id;
        if($add_sub->save())
        {
          if($request->subfeature != null){
          SubscriptionAddedfeature::where('subscription_id',$request->id)->delete();
          foreach ($request->subfeature as $key => $value)
          {
            $sub_feature = new SubscriptionAddedfeature();
            $sub_feature->subscription_id = $add_sub->id;
            $sub_feature->features_id = $value;
            $sub_feature->save();
          }
        }
          return redirect()->route('admin.subscription.list')->with('message', 'Subscription updated successfully!');
        }
       
        
    }

    public function delete($id){
         $isExist = Usersubscription::select("*")
                        ->where("subscription_id", $id)
                        ->exists();

      if($isExist){
        return response()->json([
            'error' => 'subscription plan in use'
        ]);
      }else{
      
        $subscription = subscription::find($id);
        DeleteAffectedHelper::DeleteAffectedTableData($id);
        if($subscription->is_deleted == '1'){
            $subscription->is_deleted = "0";
        } else {
            $subscription->is_deleted = "1";
        }
        $subscription->update();
        return response()->json([
            'success' => 'Record has been deleted successfully!'
        ]);
      }
  }

    
   
    public function view($id) {
        //$user = User::find($id)->toArray();
        $users = DB::table('users')
            ->leftjoin('restaurant_bank_details', 'users.id', '=', 'restaurant_bank_details.user_id')
            ->select('users.*', 'restaurant_bank_details.*')
            ->where('users.id',$id)
            ->get()->first();

        return view('admin.restaurant.view')->with('user',$users);
    }

     public function subscriberlist(Request $request){
     $permission = Admin::checkPermission(Session::get('user_id'),'Subscriber','View');
    
      if($permission == 0){
        
         return redirect()->route('admin.dashboard')->with('You dont have permission to do this action')->send();

      }else{

        if ($request->ajax())
        {
            $data =  Usersubscription::select('subscriptions.name as planname','subscriptions.price','subscriptions.validity','user_subscription.order_date','user_subscription.expiry_date','users.full_name','users.restaurant_name','users.email')
            ->join('users', 'user_subscription.restaurant_id', '=', 'users.id')
            ->join('subscriptions','user_subscription.subscription_id','=','subscriptions.id')
            ->where(['users.status'=>'1','users.is_deleted'=>'0','user_subscription.is_deleted'=>'0'])->get();

            return Datatables::of($data)
              ->addIndexColumn()
             
              ->addColumn('name', function($row){
                  return $row->restaurant_name;
              })
              ->addColumn('email', function($row){
                  return $row->email;
              })
              ->addColumn('planname', function($row){
                  return $row->planname;
              })
              ->addColumn('order_date', function($row){
                return date('d-m-Y', strtotime($row->order_date));
              })
              ->addColumn('expiry_date', function($row){
                return date('d-m-Y', strtotime($row->expiry_date));
              })
              ->addColumn('validity', function($row){
                  return $row->validity;
              })
              ->addColumn('price', function($row){
                  return $row->price;
              })
              ->addColumn('planstatus', function($row){
                return date('d-m-Y', strtotime($row->expiry_date));
              })
            
              ->rawColumns(['name','email','planname','order_date','validity','price','planstatus'])
              ->make(true);
        }
        return view('admin.subscription.subscriberlist');
    }
     }
    public function earningslist(Request $request){
     $permission = Admin::checkPermission(Session::get('user_id'),'Earnings','View');
    
      if($permission == 0){
        
         return redirect()->route('admin.dashboard')->with('You dont have permission to do this action')->send();

      }else{

        $dayfrom = now()->subDays(1);
        $weekfrom = now()->subDays(7);
        $month = now()->subDays(30);
        $to = now();

        $data['day'] = Usersubscription::whereBetween('user_subscription.order_date', [$dayfrom, $to])
        ->join('subscriptions','user_subscription.subscription_id','=','subscriptions.id')
        ->pluck('price')->sum();

        $data['week'] = Usersubscription::whereBetween('user_subscription.order_date', [$weekfrom, $to])
        ->join('subscriptions','user_subscription.subscription_id','=','subscriptions.id')
        ->pluck('price')->sum();

        $data['month'] = Usersubscription::whereBetween('user_subscription.order_date', [$month, $to])
        ->join('subscriptions','user_subscription.subscription_id','=','subscriptions.id')
        ->pluck('price')->sum();

        $data['total'] = Usersubscription::join('subscriptions','user_subscription.subscription_id','=','subscriptions.id')
        ->pluck('price')->sum();

      
        if ($request->ajax())
        {
            $earnings  = Usersubscription::select('subscriptions.name as planname','subscriptions.price','user_subscription.order_date','user_subscription.transaction_id','users.full_name','users.restaurant_name','users.email','users.mobile_number')
            ->join('users', 'user_subscription.restaurant_id', '=', 'users.id')
            ->join('subscriptions','user_subscription.subscription_id','=','subscriptions.id')
            ->where(['users.status'=>'1','users.is_deleted'=>'0','user_subscription.is_deleted'=>'0'])->get();
    

            return Datatables::of($earnings)
              ->addIndexColumn()
             
              ->addColumn('transaction_id', function($row){
                if($row->transaction_id != ''){
                  return $row->transaction_id;
                }else{
                  return '#1111';
                }
              })
              ->addColumn('transaction_date', function($row){
                 return date('d-m-Y', strtotime($row->order_date));
              })
              ->addColumn('transaction_time', function($row){
                  return date('H:i:s', strtotime($row->order_date));
              })
              ->addColumn('restaurant_name', function($row){
                  return $row->full_name.'- '.$row->restaurant_name;
              })
              ->addColumn('mobile_number', function($row){
                   return $row->mobile_number;
              })
              ->addColumn('planname', function($row){
                return $row->planname;
              })
              ->addColumn('price', function($row){
                  return $row->price;
              })
              ->rawColumns(['transaction_id','transaction_date','transaction_time','restaurant_name','mobile_number','planname','price'])
              ->make(true);
        }
        return view('admin.earnings.earnings')->with($data);
    }
     }
   
   
}
