<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;
use App\Models\Language;
use App\Models\Orders;
use DataTables;
use App\Models\Review;
use App\Helpers\s3upload;
use Illuminate\Support\Facades\Storage;
use App\Helpers\Admin;
use Session;
class UserController extends Controller
{
     /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request) {
        $permission = Admin::checkPermission(Session::get('user_id'),'Users','View');
    
      if($permission == 0){
       
           return redirect()->route('admin.dashboard')->with('message','You dont have permission to do this action')->send();


      }else{
        if ($request->ajax()) {
            $data = User::where('is_deleted','0')->get();

            return Datatables::of($data)
                    ->addIndexColumn()
                    ->addColumn('profile_image', function($row){
                        $url= env('project_image_path').'profile/'.$row->profile_image;
                        return '<img src="'.$row->profile_image.'" border="0" width="40" class="img-rounded" align="center" />';
                    })
                    ->addColumn('createdat', function($row){
                        return date('d-m-Y', strtotime($row->created_at));
                    })
                    ->addColumn('user_type', function($row){
                        return $row->user_type=='I'?'Inspector':($row->user_type=='B'?'Business':'Business Inspector');
                    })
                    ->addColumn('action', function($row){
                        $urlpath = url('admin/users');
                        $update = Admin::checkPermission(Session::get('user_id'),'Users','Update');
                        $btn = '';
                        if($update == 1){
                            $btn = '<a href="javascript:void(0);" onClick="changeStatus('.$row->id.')" class=" dropdown-item"><i class="zmdi zmdi-account zmdi-hc-fw text-secondary"></i>Block/Unblock</a>';
                        }
                        return '<div class="btn-group dot-view-acation"><a href="#" data-toggle="dropdown" class="btn btn-default btn-sm btn-icon-only transparent" title=""><i class="zmdi zmdi-more"></i></a>
                            <div class="dropdown-menu dropdown-icon-menu dropdown-menu-right"> 
                                                 <a href="'.$urlpath.'/view/'. $row->id .'" class="dropdown-item"><i class="zmdi zmdi-eye zmdi-hc-fw text-secondary"></i>View</a>
                                                 '.$btn.'</div></div>';
                    })
                    ->rawColumns(['profile_image','user_type','createdat','action'])
                    ->make(true);
        }
        return view('admin.users.list');
    }
}

    public function edit($id) {
        $user = User::find($id)->toArray();
        return view('admin.users.edit')->with('user',$user);
    }

    public function update(Request $request){
        $user = User::find($request->user_id);
        $user->full_name = $request->full_name;
        $user->mobile_number = $request->mobile_number;
        $user->email = $request->email;
        $user->is_active = $request->is_active;
        if($request->has('profile_image')){
            $file1 = $request->file()['profile_image'];
            $imageName=$file1->getClientOriginalName();
            $file = $_FILES['profile_image']['tmp_name'];
            $path = env('AWS_BUCKET_FOLDER') . env('USER_IMAGE');
            $contents = s3upload::uploadImage($imageName, $file, $path); // calling helper function
            $user->profile_image = $contents;
        }
        $user->update();
        return redirect()->route('admin.user.list')->with('message', 'User record updated successfully!');
    }

    public function delete($id){
        User::find($id)->delete();
        return response()->json([
            'success' => 'Record has been deleted successfully!'
        ]);
        // return redirect()->route('admin.user.list')->with('message', 'User record delete successfully!');
    }

    public function changeStatus($id){
        $user = User::find($id);
        if($user->is_active == '1'){
            $user->is_active = "0";
        } else {
            $user->is_active = "1";
        }
        $user->update();
        return response()->json([
            'success' => 'Record status has been changed successfully!'
        ]);
    }

    public function view($id) {
        $user = User::find($id)->toArray();

        return view('admin.users.view',compact('user'));
    }
}
