<?php

namespace App\Http\Controllers;

use DB;
use Mail;
use Carbon\Carbon;
use Illuminate\Http\Request;
use App\Helpers\EncryptDecrypt;
use App\Traits\ConsumeExternalService;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Storage;
use GuzzleHttp\Exception\GuzzleException;
use GuzzleHttp\Client;
use App\Helpers\s3upload;



class WebsiteController extends Controller
{
    use ConsumeExternalService;
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return view('website/index');
    }


    // --------------------------------LOGIN----------------------------------------

    public function login(Request $request)
    {
        // dd($request);
        if ($request->isMethod('get')) {
            return view('website/auth/signin');
        } else {
            $post_data = $request->except('_token');
            $post_data['device_type'] = "W";
            $post_data['device_token'] = "0";
            $post_data['uuid'] = "0";
            $post_data['os_version'] = "-";
            $post_data['device_name'] = "-";
            $post_data['model_name'] = "-";

            // dd($post_data);

            $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
            // dd($data);
            $response = $this->performRequest("POST", "/api/v1/user/login", $data);
            $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

            // dd($response_decoded);


            if ($response_decoded->code == 1) {
                Session::put('timezone', $request->timezone);
                Session::put('userData', $response_decoded->data);
                Session::put('user_id', $response_decoded->data->id);
                Session::put('token', EncryptDecrypt::bodyEncrypt($response_decoded->data->token));
                Session::put('user_name', $response_decoded->data->full_name);



                return redirect()->route('website.home')->with('success', $response_decoded->message);
            } else {
                return redirect()->route('website.login')->with('error', $response_decoded->message);
            }
        }
    }


    // --------------------------------------SIGNUP-----------------------------------------


    public function signup(Request $request)
    {
        if ($request->isMethod('get')) {
            return view('website/auth/signup');
        } else {
            $post_data = [];
            $post_data['full_name'] = $request->full_name;
            $post_data['email'] = $request->email;
            $post_data['country_code'] = $request->country_code;
            $post_data['phone_number'] = $request->phone_number;
            $post_data['password']     = $request->password;
            $post_data['device_type']  = "W";
            $post_data['device_token'] = '0';
            $post_data['uuid'] = '';
            $post_data['ip'] = '';
            $post_data['os_version'] = '';
            $post_data['model_name'] = '';
            $post_data['device_name'] = '';

            // dd($post_data);

            $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
            $response = $this->performRequest("POST", "/api/v1/user/signup", $data);
            $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
            if ($response_decoded->code == 1) {
                // dd($response_decoded->code);
                Session::put('timezone', $request->timezone);


                return redirect('home');
            } else {
                return redirect()->route('website.signup')->with('error', $response_decoded->message);
            }
        }
    }



    // --------------------------------SIGNUP OTP----------------------------------------


    public function sendSignupOTP(Request $request)
    {
        if ($request->isMethod('get')) {
            $expiration = Carbon::now()->addMinutes(2);
            Session::put('otp_resend_timer', $expiration);
            return view('website/auth/otp');
        } else {
            // dd($request->all());
            $post_data = [];
            $post_data['full_name'] = $request->full_name;
            $post_data['email'] = $request->email;
            $post_data['country_code'] = $request->country_code;
            $post_data['phone_number'] = $request->phone_number;
            $post_data['password']     = $request->password;
            $post_data['device_type']  = "W";
            $post_data['device_token'] = '0';
            $post_data['uuid'] = '';
            $post_data['ip'] = '';
            $post_data['os_version'] = '';
            $post_data['model_name'] = '';
            $post_data['device_name'] = '';
            Session::put('userData', $post_data);
            Session::put('timezone', $request->timezone);

            $checkuniquefieldsData = [];
            $checkuniquefieldsData['email'] = $request->email;
            $checkuniquefieldsData['country_code'] = $request->country_code;
            $checkuniquefieldsData['phone_number'] = $request->phone_number;
            $data = EncryptDecrypt::bodyEncrypt(json_encode($checkuniquefieldsData));
            $response = $this->performRequest("POST", "/api/v1/user/checkuniquefields", $data);
            $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

            if ($response_decoded->code == 1) {
                $phoneData = EncryptDecrypt::bodyEncrypt(json_encode(array('phone_number' => $request->phone_number)));
                $otpResponse = $this->performRequest("POST", "/api/v1/user/sendOtp", $phoneData);
                $otpResponse_decoded = json_decode(EncryptDecrypt::bodyDecrypt($otpResponse));
                // dd($checkuniquefieldsData);
                if ($otpResponse_decoded->code == 1) {
                    return view('website/auth/otp', $checkuniquefieldsData)->with('success', $otpResponse_decoded->message);
                } else {
                    return view('website/auth/otp', $checkuniquefieldsData)->with('error', $otpResponse_decoded->message);
                }
            } else {
                return view('website/auth/otp', $checkuniquefieldsData)->with('error', $response_decoded->message);
            }
        }
    }


    // ------------------------------------RESEND OTP-------------------------------------------


    public function resendOTP(Request $request)
    {

        $phoneData = EncryptDecrypt::bodyEncrypt(json_encode(array('phone_number' => $request->phone_number)));
        $otpResponse = $this->performRequest("POST", "/api/v1/user/sendOtp", $phoneData);
        $otpResponse_decoded = json_decode(EncryptDecrypt::bodyDecrypt($otpResponse));
        // dd($otpResponse_decoded);
        if ($otpResponse_decoded->code == 1) {
            return response()->json([
                'code' => $otpResponse_decoded->code,
                'message' => $otpResponse_decoded->message
            ]);
        } else {
            return response()->json([
                'code' => $otpResponse_decoded->code,
                'message' => $otpResponse_decoded->message
            ]);
        }
    }


    // ------------------------------VERIFY SIGNUP--------------------------------


    public function verifySignupOTP(Request $request)
    {

        $otpFields = ['otp1', 'otp2', 'otp3', 'otp4'];
        $otp = '';

        foreach ($otpFields as $field) {
            $otp .= $request->input($field);
        }
        $post_data = [];
        $post_data['otp'] = $otp;
        $post_data['phone_number'] = $request->phone_number;
        $post_data['country_code'] = $request->country_code;
        // dd($post_data);

        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/user/verifyOtp", $data);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);
        if ($response_decoded->code == "1") {
            // return redirect('addBankInfo');
            $userData = Session::get('userData');
            $user_data = EncryptDecrypt::bodyEncrypt(json_encode($userData));
            $user_response = $this->performRequest("POST", "/api/v1/user/signup", $user_data);
            $decoded_response = json_decode(EncryptDecrypt::bodyDecrypt($user_response));

            // dd($decoded_response);

            if ($decoded_response->code == "1") {
                Session::put('userData', $decoded_response->data);
                Session::put('user_id', $decoded_response->data->id);
                Session::put('token', EncryptDecrypt::bodyEncrypt($decoded_response->data->token));
                return redirect()->route('website.addBankInfo')->with('success', $response_decoded->message);
            } else {
                return view('website/auth/otp', $post_data)->with('error', $response_decoded->message);
            }
        } else {
            return view('website/auth/otp', $post_data)->with('error', $response_decoded->message);
            // return redirect()->route('website.sendSignupOTP')->with('error', $response_decoded->message);
        }
    }



    // ------------------------------------ADD BANK INFO-------------------------------


    public function addBankInfo(Request $request)
    {
        if ($request->isMethod('get')) {
            $userData['token'] = Session::get('token');
            // dd($userData);
            // $postData = EncryptDecrypt::bodyEncrypt(json_encode($userData));
            $response = $this->performRequest("POST", "/api/v1/user/getbank", null, $userData);
            $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

            if ($response_decoded->code == "1") {
                // return redirect('addBankInfo');
                $data['bank_list'] = $response_decoded->data;
                // dd($data);
                return view('website/addbankdetail', $data)->with('success', $response_decoded->message);
            } else {
                return view('website/addbankdetail')->with('error', $response_decoded->message);
            }
        } else {
            $data = $request->except('_token');
            // dd($data);
            $headerData['token'] = Session::get('token');
            $postData = EncryptDecrypt::bodyEncrypt(json_encode($data));
            $response = $this->performRequest("POST", "/api/v1/user/bankdetail", $postData, $headerData);
            $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
            // dd($response_decoded);
            if ($response_decoded->code == "1") {
                return view('website/successmessage')->with('success', $response_decoded->message);
            } else {
                $userData['token'] = Session::get('token');
                $response = $this->performRequest("POST", "/api/v1/user/getbank", null, $userData);
                $decoded_response = json_decode(EncryptDecrypt::bodyDecrypt($response));
                $data['bank_list'] = $decoded_response->data;
                // dd($data);
                return view('website/addbankdetail', $data)->with('success', $decoded_response->message);
            }
        }
    }



    public function bank_details(Request $request)
    {
        $userData['token'] = Session::get('token');
        $response = $this->performRequest("POST", "/api/v1/user/getbankdetail", null, $userData);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        $data = []; // Initialize the data array

        if ($response_decoded->code == "1") {
            $data['code'] = $response_decoded->code;
            $data['data'] = $response_decoded->data;

            $bank_id = $response_decoded->data[0]->bank_id;

            // dd($bank_id);


            $bankData = EncryptDecrypt::bodyEncrypt(json_encode(['id' => $bank_id]));

            $userData['token'] = Session::get('token');
            $response = $this->performRequest("POST", "/api/v1/user/getbank", $bankData, $userData);
            $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

            if ($response_decoded->code == "1") {
                $data['bank_code'] = $response_decoded->code;
                $data['bank_data'] = $response_decoded->data;
            } else {
                $data['bank_code'] = $response_decoded->code;
                $data['bank_data'] = [];
            }
        } else {
            $data['code'] = $response_decoded->code;
            $data['bank_info'] = [];
            $data['bank_code'] = 0;
            $data['bank_data'] = [];
        }

        // Get schedule inspection list

        // dd($data);

        return view('website/bank_details', $data);
    }



    // --------------delete bank 


    public function delete_bank(Request $request)
    {

        $data['id'] = $request->id;


        $headerData['token'] = Session::get('token');
        $postData = EncryptDecrypt::bodyEncrypt(json_encode($data));
        $response = $this->performRequest("POST", "/api/v1/user/deletebankdetail", $postData, $headerData);
        // dd($response); 
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));



        return redirect()->route('website.settings');
    }



    // -------------------------------------HOME-------------------------------------

    public function home()
    {
        $currentDate = date('j F, Y');

        // Get user info

        $userData['token'] = Session::get('token');
        $response = $this->performRequest("POST", "/api/v1/user/userinfo", null, $userData);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);

        if ($response_decoded->code == "1") {
            $data['code'] = $response_decoded->code;
            $data['user_info'] = $response_decoded->data;
        } else {
            $data['code'] = $response_decoded->code;
            $data['user_info'] = [];
        }

        // Get schedule inspection list

        $userData['token'] = Session::get('token');
        $response = $this->performRequest("POST", "/api/v1/user/scheduleinspectionlist", null, $userData);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);

        if ($response_decoded->code == "1") {
            $data['code'] = $response_decoded->code;
            $data['data'] = $response_decoded->data;
        } else {
            $data['code'] = $response_decoded->code;
            $data['data'] = [];
        }

        $data['currentDate'] = $currentDate;
        // dd($data);

        return view('website/home', $data);
    }



    // -------------------------------------SIGNOUT--------------------------------------


    public function signout()
    {
        $userData['token'] = Session::get('token');
        $response = $this->performRequest("POST", "/api/v1/user/signout", null, $userData);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);
        if ($response_decoded->code == "1") {
            Session::flush();
            return redirect()->route('index')->with('success', $response_decoded->message);
        } else {
            return redirect()->route('website.home')->with('error', $response_decoded->message);
        }
    }


    // -----------------------------FORGOT PASSWORD-------------------------------



    public function forgotPassword(Request $request)
    {
        if ($request->isMethod('get')) {
            return view('website/auth/forgot');
        } else {

            $emailData = EncryptDecrypt::bodyEncrypt(json_encode(array('email' => $request->email)));
            $emailResponse = $this->performRequest("POST", "/api/v1/user/forgotPassword", $emailData);
            $emailResponse_decoded = json_decode(EncryptDecrypt::bodyDecrypt($emailResponse));
            
            dd($emailResponse_decoded);

            if ($emailResponse_decoded->code == "1") {
                return redirect()->route('website.home')->with('success', $emailResponse_decoded->message);
            } else {
                return redirect()->route('website.forgotPassword')->with('error', $emailResponse_decoded->message);
            }
        }
    }



    // ----------------------------CONTAC US------------------------------

    public function contactus()
    {
        return view('website/contact');
    }

    // --------------------------ABOUT US-----------------------------

    public function aboutus()
    {
        return view('website/aboutus');
    }

    // -------------------------------SETTINGS------------------------------

    public function settings(Request $request)
    {
        if ($request->isMethod('get')) {

            $userData['token'] = Session::get('token');
            $response = $this->performRequest("POST", "/api/v1/user/userinfo", null, $userData);
            $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

            if ($response_decoded->code == "1") {
                $data['code'] = $response_decoded->code;
                $data['business_details'] = [$response_decoded->data];
            } else {
                $data['code'] = $response_decoded->code;
                $data['business_details'] = [];
            }

            return view('website/settings', $data);
        } else {
            //    dd($request);
            $businessData['business_name'] = $request->business_name;
            $businessData['business_email'] = $request->business_email;
            $businessData['country_code'] = $request->country_code;
            $businessData['phone_number'] = $request->phone_number;
            //    dd($request->file());
            if ($request->has('business_logo')) {
                $file1 = $request->file()['business_logo'];
                $imageName = $file1->getClientOriginalName();
                $file = $_FILES['business_logo']['tmp_name'];
                $path = env('AWS_BUCKET_FOLDER') . env('BUSINESS_LOGO');
                $contents = s3upload::uploadImage($imageName, $file, $path); // calling helper function
                $businessData['business_logo'] = $contents;
            }
            $businessData['business_address'] = $request->business_address;

            $businessData['latitude'] = 0;
            $businessData['longitude'] = 0;
            dd($businessData);

            $headerData['token'] = Session::get('token');

            $business_Data = EncryptDecrypt::bodyEncrypt(json_encode($businessData));
            $response = $this->performRequest("POST", "/api/v1/user/setbusinessinfo", $business_Data, $headerData);
            $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
            // dd($response_decoded);


            return redirect()->route('website.settings');
        }
    }


    // --------change password


    public function change_password(Request $request)
    {
        if ($request->isMethod('get')) {
            return view('website.change_password');
        } else {

            $post_data = [];
            $post_data['old_password'] = $request->old_password;
            $post_data['new_password'] = $request->new_password;


            $headerData['token'] = Session::get('token');

            $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
            $response = $this->performRequest("POST", "/api/v1/user/changePassword", $data, $headerData);
            $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));



            if ($response_decoded->code == 1) {
                return redirect()->route('website.login');
            } else {
                return redirect()->route('website.settings')->with('error', $response_decoded->message);
            }
        }
    }


    // ---------------edit profile


    public function edit_profile(Request $request)
    {
        if ($request->isMethod('get')) {
            $userData['token'] = Session::get('token');
            $response = $this->performRequest("POST", "/api/v1/user/userinfo", null, $userData);
            $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
            // dd($response_decoded);

            if ($response_decoded->code == "1") {
                $data['code'] = $response_decoded->code;
                $data['user_info'] = $response_decoded->data;
            } else {
                $data['code'] = $response_decoded->code;
                $data['user_info'] = [];
            }


            return view('website.edit-profile', $data);
        } else {



            $data['full_name'] = $request->full_name;
            $data['email'] = $request->email;
            $data['country_code'] = $request->country_code;
            $data['phone_number'] = $request->phone_number;
            $data['inspector_license_number'] = $request->inspector_license_number;

            if ($request->has('profile_image')) {
                $file1 = $request->file()['profile_image'];
                $imageName = $file1->getClientOriginalName();
                $file = $_FILES['profile_image']['tmp_name'];
                $path = env('AWS_BUCKET_FOLDER') . env('USER_IMAGES');
                $contents = s3upload::uploadImage($imageName, $file, $path); // calling helper function
                $data['profile_image'] = $contents;
            }

            if ($request->has('signature')) {
                $file1 = $request->file()['signature'];
                $imageName = $file1->getClientOriginalName();
                $file = $_FILES['signature']['tmp_name'];
                $path = env('AWS_BUCKET_FOLDER') . env('SIGNATURE');
                $contents = s3upload::uploadImage($imageName, $file, $path); // calling helper function
                $data['signature'] = $contents;
            }

            // dd($data);

            $headerData['token'] = Session::get('token');
            $postData = EncryptDecrypt::bodyEncrypt(json_encode($data));
            $response = $this->performRequest("POST", "/api/v1/user/editprofile", $postData, $headerData);
            // dd($response);
            $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

            // dd($response_decoded);

            if ($response_decoded->code == 1) {
                $data['code'] = $response_decoded->code;
                $data['data'] = $response_decoded->data;
            } else {
                $data['code'] = $response_decoded->code;
                $data['data'] = [];
            }
            // dd('data', $data);
            return redirect()->route('website.home');
        }
    }
}
