@extends('layout.website')
@section('title') Sign In @endsection
@section('content')
<section class="vh-100 section-img bg-overlay-theme-black-90 ">
    <div class="login-section">
        <div class="login">
            <div class="header">
                <a href="{{route('index')}}">
                    <img src="web_assets/img/logo.svg" alt="" class="img-fluid">
                </a>
                <h1 class="title">Sign In</h1>
                <span class="sub-title">Welcome back !</span>
            </div>
            <div class="body">
                <form id="sign_in" action="{{route('website.login')}}" method="post" autocomplete="off">
                    @csrf
                    <div class="form-group form-float">
                        <div class="form-line">
                            <input type="email" id="email" name="email" placeholder="Enter Email" autocomplete="new-password">
                            @error('email')
                            <label class="error" role="alert">{{ $message }}</label>
                            @enderror
                        </div>
                    </div>

                    <div class="form-group form-float">
                        <div class="form-line">
                            <input type="password" id="password" name="password" placeholder="Create Password" autocomplete="new-password">
                            @error('password')
                            <label class="error" role="alert">{{ $message }}</label>
                            @enderror
                        </div>
                    </div>
                    <a href="{{route('website.forgotPassword')}}" style="float:right;">Forgot your password ?</a>

                    <input type="hidden" name="timezone" id="timezone" value="">

                    <input type="submit" value="Sign In" class="btn btn-raised btn-yellow waves-effect btn btn-orange w-100 mt-3">
                </form>
                <div class="text-center p-2">
                    Don't have an account ? <a href="{{route('website.signup')}}" class="text-black fw-bold">Create an account</a>
                </div>
            </div>
        </div>
    </div>
</section>

@endsection
@section('script')
<script src="web_assets/js/jstz.min.js"></script>
<script>
    var timezone = jstz.determine();
    $('#timezone').val(timezone.name());

    jQuery.validator.addMethod("validEmail", function(value, element) {
        var emailRegex = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
        return this.optional(element) || (emailRegex.test(String(value).toLowerCase()));
    }, "Please enter a valid email");

    $("#sign_in").validate({
        rules: {
            "email": {
                required: true,
                email: email,
                validEmail: true,
            },
            "password": {
                required: true,
            }
        },
        messages: {
            email: {
                required: "Please enter email",
                email: "Please enter a valid email",
            },
            password: {
                required: 'Please enter password',
            },
        },
        submitHandler: function(form) {
            loader('show');
            form.submit();
        },
        highlight: function(input) {
            $(input).parents('.form-line').addClass('error');
        },
        unhighlight: function(input) {
            $(input).parents('.form-line').removeClass('error');
        },
        errorPlacement: function(error, element) {
            $(element).parents('.form-group').append(error);
        }
    });
</script>
@endsection